@@ -40,6 +40,7 @@
 #define CURL_GLOBAL_NOTHING_FIRST 0x070800 /* Added in 7.8 */
 #define CURL_GLOBAL_SSL_FIRST 0x070800 /* Added in 7.8 */
 #define CURL_GLOBAL_WIN32_FIRST 0x070801 /* Added in 7.8.1 */
+#define CURL_HAS_DECLSPEC_ATTRIBUTE_FIRST 0x080d00 /* Added in 8.13.0 */
 #define CURL_HET_DEFAULT_FIRST 0x073b00 /* Added in 7.59.0 */
 #define CURL_HTTP_VERSION_1_0_FIRST 0x070901 /* Added in 7.9.1 */
 #define CURL_HTTP_VERSION_1_1_FIRST 0x070901 /* Added in 7.9.1 */
@@ -63,6 +64,7 @@
 #define CURL_IPRESOLVE_V6_FIRST 0x070a08 /* Added in 7.10.8 */
 #define CURL_IPRESOLVE_WHATEVER_FIRST 0x070a08 /* Added in 7.10.8 */
 #define CURL_ISOCPP_FIRST 0x070a02 /* Added in 7.10.2 */
+#define CURL_ISOCPP_LAST 0x080e01 /* Last featured in 8.14.1 */
 #define CURL_LOCK_ACCESS_NONE_FIRST 0x070a03 /* Added in 7.10.3 */
 #define CURL_LOCK_ACCESS_SHARED_FIRST 0x070a03 /* Added in 7.10.3 */
 #define CURL_LOCK_ACCESS_SINGLE_FIRST 0x070a03 /* Added in 7.10.3 */
@@ -111,7 +113,7 @@
 #define CURL_REDIR_GET_ALL_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURL_REDIR_POST_301_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURL_REDIR_POST_302_FIRST 0x071301 /* Added in 7.19.1 */
-#define CURL_REDIR_POST_303_FIRST 0x071901 /* Added in 7.25.1 */
+#define CURL_REDIR_POST_303_FIRST 0x071a00 /* Added in 7.26.0 */
 #define CURL_REDIR_POST_ALL_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURL_RTSPREQ_ANNOUNCE_FIRST 0x071400 /* Added in 7.20.0 */
 #define CURL_RTSPREQ_DESCRIBE_FIRST 0x071400 /* Added in 7.20.0 */
@@ -193,6 +195,7 @@
 #define CURL_WAIT_POLLOUT_FIRST 0x071c00 /* Added in 7.28.0 */
 #define CURL_WAIT_POLLPRI_FIRST 0x071c00 /* Added in 7.28.0 */
 #define CURL_WIN32_FIRST 0x074500 /* Added in 7.69.0 */
+#define CURL_WIN32_LAST 0x080500 /* Last featured in 8.5.0 */
 #define CURL_WRITEFUNC_ERROR_FIRST 0x075700 /* Added in 7.87.0 */
 #define CURL_WRITEFUNC_PAUSE_FIRST 0x071200 /* Added in 7.18.0 */
 #define CURL_ZERO_TERMINATED_FIRST 0x073800 /* Added in 7.56.0 */
@@ -330,6 +333,7 @@
 #define CURLE_TFTP_NOTFOUND_FIRST 0x070f00 /* Added in 7.15.0 */
 #define CURLE_TFTP_PERM_FIRST 0x070f00 /* Added in 7.15.0 */
 #define CURLE_TFTP_UNKNOWNID_FIRST 0x070f00 /* Added in 7.15.0 */
+#define CURLE_TOO_LARGE_FIRST 0x080600 /* Added in 8.6.0 */
 #define CURLE_TOO_MANY_REDIRECTS_FIRST 0x070500 /* Added in 7.5 */
 #define CURLE_UNKNOWN_OPTION_FIRST 0x071505 /* Added in 7.21.5 */
 #define CURLE_UNKNOWN_TELNET_OPTION_FIRST 0x070700 /* Added in 7.7 */
@@ -337,6 +341,7 @@
 #define CURLE_UNSUPPORTED_PROTOCOL_FIRST 0x070100 /* Added in 7.1 */
 #define CURLE_UPLOAD_FAILED_FIRST 0x071003 /* Added in 7.16.3 */
 #define CURLE_URL_MALFORMAT_FIRST 0x070100 /* Added in 7.1 */
+#define CURLE_ECH_REQUIRED_FIRST 0x080800 /* Added in 8.8.0 */
 #define CURLE_URL_MALFORMAT_USER_FIRST 0x070100 /* Added in 7.1 */
 #define CURLE_USE_SSL_FAILED_FIRST 0x071100 /* Added in 7.17.0 */
 #define CURLE_WEIRD_SERVER_REPLY_FIRST 0x073300 /* Added in 7.51.0 */
@@ -358,6 +363,9 @@
 #define CURLFINFOFLAG_KNOWN_SIZE_FIRST 0x071500 /* Added in 7.21.0 */
 #define CURLFINFOFLAG_KNOWN_TIME_FIRST 0x071500 /* Added in 7.21.0 */
 #define CURLFINFOFLAG_KNOWN_UID_FIRST 0x071500 /* Added in 7.21.0 */
+#define CURLFOLLOW_ALL_FIRST 0x080d00 /* Added in 8.13.0 */
+#define CURLFOLLOW_OBEYCODE_FIRST 0x080d00 /* Added in 8.13.0 */
+#define CURLFOLLOW_FIRSTONLY_FIRST 0x080d00 /* Added in 8.13.0 */
 #define CURLFORM_ARRAY_FIRST 0x070901 /* Added in 7.9.1 */
 #define CURLFORM_ARRAY_END_FIRST 0x070901 /* Added in 7.9.1 */
 #define CURLFORM_ARRAY_END_LAST 0x070906 /* Last featured in 7.9.6 */
@@ -425,6 +433,7 @@
 #define CURLINFO_CAPATH_FIRST 0x075400 /* Added in 7.84.0 */
 #define CURLINFO_CERTINFO_FIRST 0x071301 /* Added in 7.19.1 */
 #define CURLINFO_CONDITION_UNMET_FIRST 0x071304 /* Added in 7.19.4 */
+#define CURLINFO_CONN_ID_FIRST 0x080200 /* Added in 8.2.0 */
 #define CURLINFO_CONNECT_TIME_FIRST 0x070401 /* Added in 7.4.1 */
 #define CURLINFO_CONNECT_TIME_T_FIRST 0x073d00 /* Added in 7.61.0 */
 #define CURLINFO_CONTENT_LENGTH_DOWNLOAD_FIRST 0x070601 /* Added in 7.6.1 */
@@ -436,6 +445,7 @@
 #define CURLINFO_DATA_IN_FIRST 0x070906 /* Added in 7.9.6 */
 #define CURLINFO_DATA_OUT_FIRST 0x070906 /* Added in 7.9.6 */
 #define CURLINFO_DOUBLE_FIRST 0x070401 /* Added in 7.4.1 */
+#define CURLINFO_EARLYDATA_SENT_T_FIRST 0x080b00 /* Added in 8.11.0 */
 #define CURLINFO_EFFECTIVE_METHOD_FIRST 0x074800 /* Added in 7.72.0 */
 #define CURLINFO_EFFECTIVE_URL_FIRST 0x070400 /* Added in 7.4 */
 #define CURLINFO_END_FIRST 0x070906 /* Added in 7.9.6 */
@@ -449,6 +459,7 @@
 #define CURLINFO_HTTP_CONNECTCODE_FIRST 0x070a07 /* Added in 7.10.7 */
 #define CURLINFO_HTTP_VERSION_FIRST 0x073200 /* Added in 7.50.0 */
 #define CURLINFO_HTTPAUTH_AVAIL_FIRST 0x070a08 /* Added in 7.10.8 */
+#define CURLINFO_HTTPAUTH_USED_FIRST 0x080c00 /* Added in 8.12.0 */
 #define CURLINFO_LASTONE_FIRST 0x070401 /* Added in 7.4.1 */
 #define CURLINFO_LASTSOCKET_FIRST 0x070f02 /* Added in 7.15.2 */
 #define CURLINFO_LOCAL_IP_FIRST 0x071500 /* Added in 7.21.0 */
@@ -463,6 +474,7 @@
 #define CURLINFO_OS_ERRNO_FIRST 0x070c02 /* Added in 7.12.2 */
 #define CURLINFO_PRETRANSFER_TIME_FIRST 0x070401 /* Added in 7.4.1 */
 #define CURLINFO_PRETRANSFER_TIME_T_FIRST 0x073d00 /* Added in 7.61.0 */
+#define CURLINFO_POSTTRANSFER_TIME_T_FIRST 0x080a00 /* Added in 8.10.0 */
 #define CURLINFO_PRIMARY_IP_FIRST 0x071300 /* Added in 7.19.0 */
 #define CURLINFO_PRIMARY_PORT_FIRST 0x071500 /* Added in 7.21.0 */
 #define CURLINFO_PRIVATE_FIRST 0x070a03 /* Added in 7.10.3 */
@@ -470,7 +482,9 @@
 #define CURLINFO_PROXY_ERROR_FIRST 0x074900 /* Added in 7.73.0 */
 #define CURLINFO_PROXY_SSL_VERIFYRESULT_FIRST 0x073400 /* Added in 7.52.0 */
 #define CURLINFO_PROXYAUTH_AVAIL_FIRST 0x070a08 /* Added in 7.10.8 */
+#define CURLINFO_PROXYAUTH_USED_FIRST 0x080c00 /* Added in 8.12.0 */
 #define CURLINFO_PTR_FIRST 0x073601 /* Added in 7.54.1 */
+#define CURLINFO_QUEUE_TIME_T_FIRST 0x080600 /* Added in 8.6.0 */
 #define CURLINFO_REDIRECT_COUNT_FIRST 0x070907 /* Added in 7.9.7 */
 #define CURLINFO_REDIRECT_TIME_FIRST 0x070907 /* Added in 7.9.7 */
 #define CURLINFO_REDIRECT_TIME_T_FIRST 0x073d00 /* Added in 7.61.0 */
@@ -507,6 +521,8 @@
 #define CURLINFO_TOTAL_TIME_FIRST 0x070401 /* Added in 7.4.1 */
 #define CURLINFO_TOTAL_TIME_T_FIRST 0x073d00 /* Added in 7.61.0 */
 #define CURLINFO_TYPEMASK_FIRST 0x070401 /* Added in 7.4.1 */
+#define CURLINFO_USED_PROXY_FIRST 0x080700 /* Added in 8.7.0 */
+#define CURLINFO_XFER_ID_FIRST 0x080200 /* Added in 8.2.0 */
 #define CURLIOCMD_NOP_FIRST 0x070c03 /* Added in 7.12.3 */
 #define CURLIOCMD_RESTARTREAD_FIRST 0x070c03 /* Added in 7.12.3 */
 #define CURLIOE_FAILRESTART_FIRST 0x070c03 /* Added in 7.12.3 */
@@ -527,7 +543,7 @@
 #define CURLKHTYPE_RSA1_FIRST 0x071306 /* Added in 7.19.6 */
 #define CURLKHTYPE_UNKNOWN_FIRST 0x071306 /* Added in 7.19.6 */
 #define CURLM_ABORTED_BY_CALLBACK_FIRST 0x075100 /* Added in 7.81.0 */
-#define CURLM_ADDED_ALREADY_FIRST 0x072001 /* Added in 7.32.1 */
+#define CURLM_ADDED_ALREADY_FIRST 0x072100 /* Added in 7.33.0 */
 #define CURLM_BAD_EASY_HANDLE_FIRST 0x070906 /* Added in 7.9.6 */
 #define CURLM_BAD_FUNCTION_ARGUMENT_FIRST 0x074500 /* Added in 7.69.0 */
 #define CURLM_BAD_HANDLE_FIRST 0x070906 /* Added in 7.9.6 */
@@ -617,6 +633,7 @@
 #define CURLOPT_DOH_SSL_VERIFYPEER_FIRST 0x074c00 /* Added in 7.76.0 */
 #define CURLOPT_DOH_SSL_VERIFYSTATUS_FIRST 0x074c00 /* Added in 7.76.0 */
 #define CURLOPT_DOH_URL_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURLOPT_ECH_FIRST 0x080800 /* Added in 8.8.0 */
 #define CURLOPT_EGDSOCKET_FIRST 0x070700 /* Added in 7.7 */
 #define CURLOPT_ENCODING_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLOPT_ERRORBUFFER_FIRST 0x070100 /* Added in 7.1 */
@@ -649,6 +666,7 @@
 #define CURLOPT_GSSAPI_DELEGATION_FIRST 0x071600 /* Added in 7.22.0 */
 #define CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS_FIRST 0x073b00 /* Added in 7.59.0 */
 #define CURLOPT_HAPROXYPROTOCOL_FIRST 0x073c00 /* Added in 7.60.0 */
+#define CURLOPT_HAPROXY_CLIENT_IP_FIRST 0x080200 /* Added in 8.2.0 */
 #define CURLOPT_HEADER_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_HEADERDATA_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLOPT_HEADERFUNCTION_FIRST 0x070702 /* Added in 7.7.2 */
@@ -696,6 +714,7 @@
 #define CURLOPT_MAIL_FROM_FIRST 0x071400 /* Added in 7.20.0 */
 #define CURLOPT_MAIL_RCPT_FIRST 0x071400 /* Added in 7.20.0 */
 #define CURLOPT_MAIL_RCPT_ALLLOWFAILS_FIRST 0x074500 /* Added in 7.69.0 */
+#define CURLOPT_MAIL_RCPT_ALLOWFAILS_FIRST 0x080200 /* Added in 8.2.0 */
 #define CURLOPT_QUICK_EXIT_FIRST 0x075700 /* Added in 7.87.0 */
 #define CURLOPT_MAX_RECV_SPEED_LARGE_FIRST 0x070f05 /* Added in 7.15.5 */
 #define CURLOPT_MAX_SEND_SPEED_LARGE_FIRST 0x070f05 /* Added in 7.15.5 */
@@ -808,6 +827,7 @@
 #define CURLOPT_SEEKDATA_FIRST 0x071200 /* Added in 7.18.0 */
 #define CURLOPT_SEEKFUNCTION_FIRST 0x071200 /* Added in 7.18.0 */
 #define CURLOPT_SERVER_RESPONSE_TIMEOUT_FIRST 0x071400 /* Added in 7.20.0 */
+#define CURLOPT_SERVER_RESPONSE_TIMEOUT_MS_FIRST 0x080600 /* Added in 8.6.0 */
 #define CURLOPT_SERVICE_NAME_FIRST 0x072b00 /* Added in 7.43.0 */
 #define CURLOPT_SHARE_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLOPT_SOCKOPTDATA_FIRST 0x071000 /* Added in 7.16.0 */
@@ -851,6 +871,7 @@
 #define CURLOPT_SSL_FALSESTART_FIRST 0x072a00 /* Added in 7.42.0 */
 #define CURLOPT_SSL_OPTIONS_FIRST 0x071900 /* Added in 7.25.0 */
 #define CURLOPT_SSL_SESSIONID_CACHE_FIRST 0x071000 /* Added in 7.16.0 */
+#define CURLOPT_SSL_SIGNATURE_ALGORITHMS_FIRST 0x080e00 /* Added in 8.14.0 */
 #define CURLOPT_SSL_VERIFYHOST_FIRST 0x070801 /* Added in 7.8.1 */
 #define CURLOPT_SSL_VERIFYPEER_FIRST 0x070402 /* Added in 7.4.2 */
 #define CURLOPT_SSL_VERIFYSTATUS_FIRST 0x072900 /* Added in 7.41.0 */
@@ -874,6 +895,7 @@
 #define CURLOPT_TCP_KEEPALIVE_FIRST 0x071900 /* Added in 7.25.0 */
 #define CURLOPT_TCP_KEEPIDLE_FIRST 0x071900 /* Added in 7.25.0 */
 #define CURLOPT_TCP_KEEPINTVL_FIRST 0x071900 /* Added in 7.25.0 */
+#define CURLOPT_TCP_KEEPCNT_FIRST 0x080900 /* Added in 8.9.0 */
 #define CURLOPT_TCP_NODELAY_FIRST 0x070b02 /* Added in 7.11.2 */
 #define CURLOPT_TELNETOPTIONS_FIRST 0x070700 /* Added in 7.7 */
 #define CURLOPT_TFTP_BLKSIZE_FIRST 0x071304 /* Added in 7.19.4 */
@@ -896,6 +918,7 @@
 #define CURLOPT_UPKEEP_INTERVAL_MS_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLOPT_UPLOAD_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_UPLOAD_BUFFERSIZE_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURLOPT_UPLOAD_FLAGS_FIRST 0x080d00 /* Added in 8.13.0 */
 #define CURLOPT_URL_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_USE_SSL_FIRST 0x071100 /* Added in 7.17.0 */
 #define CURLOPT_USERAGENT_FIRST 0x070100 /* Added in 7.1 */
@@ -1063,6 +1086,7 @@
 #define CURLSSLOPT_NO_PARTIALCHAIN_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURLSSLOPT_NO_REVOKE_FIRST 0x072c00 /* Added in 7.44.0 */
 #define CURLSSLOPT_REVOKE_BEST_EFFORT_FIRST 0x074600 /* Added in 7.70.0 */
+#define CURLSSLOPT_EARLYDATA_FIRST 0x080b00 /* Added in 8.11.0 */
 #define CURLSSLSET_NO_BACKENDS_FIRST 0x073800 /* Added in 7.56.0 */
 #define CURLSSLSET_OK_FIRST 0x073800 /* Added in 7.56.0 */
 #define CURLSSLSET_TOO_LATE_FIRST 0x073800 /* Added in 7.56.0 */
@@ -1075,11 +1099,14 @@
 #define CURLU_DEFAULT_PORT_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_DEFAULT_SCHEME_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_DISALLOW_USER_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURLU_GET_EMPTY_FIRST 0x080800 /* Added in 8.8.0 */
 #define CURLU_GUESS_SCHEME_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_NO_AUTHORITY_FIRST 0x074300 /* Added in 7.67.0 */
 #define CURLU_NO_DEFAULT_PORT_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURLU_NO_GUESS_SCHEME_FIRST 0x080900 /* Added in 8.9.0 */
 #define CURLU_NON_SUPPORT_SCHEME_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_PATH_AS_IS_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURLU_PUNY2IDN_FIRST 0x080300 /* Added in 8.3.0 */
 #define CURLU_PUNYCODE_FIRST 0x075800 /* Added in 7.88.0 */
 #define CURLU_URLDECODE_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_URLENCODE_FIRST 0x073e00 /* Added in 7.62.0 */
@@ -1110,6 +1137,7 @@
 #define CURLUE_NO_ZONEID_FIRST 0x075100 /* Added in 7.81.0 */
 #define CURLUE_OK_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLUE_OUT_OF_MEMORY_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURLUE_TOO_LARGE_FIRST 0x080600 /* Added in 8.6.0 */
 #define CURLUE_UNKNOWN_PART_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLUE_UNSUPPORTED_SCHEME_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLUE_URLDECODE_FIRST 0x073e00 /* Added in 7.62.0 */
@@ -1125,6 +1153,11 @@
 #define CURLUPART_URL_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLUPART_USER_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLUPART_ZONEID_FIRST 0x074100 /* Added in 7.65.0 */
+#define CURLULFLAG_ANSWERED_FIRST 0x080d00 /* Added in 8.13.0 */
+#define CURLULFLAG_DELETED_FIRST 0x080d00 /* Added in 8.13.0 */
+#define CURLULFLAG_DRAFT_FIRST 0x080d00 /* Added in 8.13.0 */
+#define CURLULFLAG_FLAGGED_FIRST 0x080d00 /* Added in 8.13.0 */
+#define CURLULFLAG_SEEN_FIRST 0x080d00 /* Added in 8.13.0 */
 #define CURLUSESSL_ALL_FIRST 0x071100 /* Added in 7.17.0 */
 #define CURLUSESSL_CONTROL_FIRST 0x071100 /* Added in 7.17.0 */
 #define CURLUSESSL_NONE_FIRST 0x071100 /* Added in 7.17.0 */
@@ -1141,10 +1174,12 @@
 #define CURLVERSION_SIXTH_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURLVERSION_TENTH_FIRST 0x074d00 /* Added in 7.77.0 */
 #define CURLVERSION_THIRD_FIRST 0x070c00 /* Added in 7.12.0 */
+#define CURLVERSION_TWELFTH_FIRST 0x080800 /* Added in 8.8.0 */
 #define CURLWARNING_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURLWS_BINARY_FIRST 0x075600 /* Added in 7.86.0 */
 #define CURLWS_CLOSE_FIRST 0x075600 /* Added in 7.86.0 */
 #define CURLWS_CONT_FIRST 0x075600 /* Added in 7.86.0 */
+#define CURLWS_NOAUTOPONG_FIRST 0x080e00 /* Added in 8.14.0 */
 #define CURLWS_OFFSET_FIRST 0x075600 /* Added in 7.86.0 */
 #define CURLWS_PING_FIRST 0x075600 /* Added in 7.86.0 */
 #define CURLWS_PONG_FIRST 0x075600 /* Added in 7.86.0 */
